==> huaweicloudsdkclassroom-3.0.47-py2.py3-none-any.whl: huaweicloudsdkclassroom/v3/model/list_member_job_records_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListMemberJobRecordsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'records': 'list[JobRecords]',
        'total': 'int'
    }

    attribute_map = {
        'records': 'records',
        'total': 'total'
    }

    def __init__(self, records=None, total=None):
        """ListMemberJobRecordsResponse - a model defined in huaweicloud sdk"""
        
        super(ListMemberJobRecordsResponse, self).__init__()

        self._records = None
        self._total = None
        self.discriminator = None

        if records is not None:
            self.records = records
        if total is not None:
            self.total = total

    @property
    def records(self):
        """Gets the records of this ListMemberJobRecordsResponse.

        习题提交列表信息

        :return: The records of this ListMemberJobRecordsResponse.
        :rtype: list[JobRecords]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this ListMemberJobRecordsResponse.

        习题提交列表信息

        :param records: The records of this ListMemberJobRecordsResponse.
        :type: list[JobRecords]
        """
        self._records = records

    @property
    def total(self):
        """Gets the total of this ListMemberJobRecordsResponse.

        习题提交总次数

        :return: The total of this ListMemberJobRecordsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListMemberJobRecordsResponse.

        习题提交总次数

        :param total: The total of this ListMemberJobRecordsResponse.
        :type: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListMemberJobRecordsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkclassroom-3.0.52-py2.py3-none-any.whl: huaweicloudsdkclassroom/v3/model/list_member_job_records_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListMemberJobRecordsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'records': 'list[JobRecords]',
        'total': 'int'
    }

    attribute_map = {
        'records': 'records',
        'total': 'total'
    }

    def __init__(self, records=None, total=None):
        """ListMemberJobRecordsResponse - a model defined in huaweicloud sdk"""
        
        super(ListMemberJobRecordsResponse, self).__init__()

        self._records = None
        self._total = None
        self.discriminator = None

        if records is not None:
            self.records = records
        if total is not None:
            self.total = total

    @property
    def records(self):
        """Gets the records of this ListMemberJobRecordsResponse.

        习题提交列表信息

        :return: The records of this ListMemberJobRecordsResponse.
        :rtype: list[JobRecords]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this ListMemberJobRecordsResponse.

        习题提交列表信息

        :param records: The records of this ListMemberJobRecordsResponse.
        :type: list[JobRecords]
        """
        self._records = records

    @property
    def total(self):
        """Gets the total of this ListMemberJobRecordsResponse.

        习题提交总次数

        :return: The total of this ListMemberJobRecordsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListMemberJobRecordsResponse.

        习题提交总次数

        :param total: The total of this ListMemberJobRecordsResponse.
        :type: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListMemberJobRecordsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
